#
# RedOS Welcome window utility
# Version: 1.8
# Copyright (c) 2022 Vladlen Murylyov, RED SOFT.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 3.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

# !/usr/bin/python3
import gettext
import re
import time
import gi
import os
import platform
import subprocess
import locale
import threading
from redoswelcome.localinstall import RedosWelcomeDNF
# from localinstall import RedosWelcomeDNF

from redoswelcome.common import AsyncWorker
# from common import AsyncWorker

gi.require_version("Gtk", "3.0")
from gi.repository import Gtk, Gio, Gdk, GdkPixbuf, GLib, GObject

NORUN_FLAG = os.path.expanduser("~/.redoswelcome/norun.flag")

gettext.install("redoswelcome", "/usr/share/locale")
# gettext.install("redoswelcome", "data/locale")

from locale import gettext as _

locale.bindtextdomain("redoswelcome", "/usr/share/locale")
# locale.bindtextdomain("redoswelcome", "data/locale")

locale.textdomain("redoswelcome")

LAYOUT_STYLE_LEGACY, LAYOUT_STYLE_NEW = range(2)

builder = Gtk.Builder()
builder.set_translation_domain("redoswelcome")

builder.add_from_file('/usr/share/redos/redoswelcome/ui/redoswelcome.ui')
# builder.add_from_file('data/ui/redoswelcome.ui')

VERSION = "2.5"


class MyException(Exception):
    pass


class RedosWelcome:
    def __init__(self):
        window = builder.get_object("main_window")
        window.set_icon_name("start-here")
        window.set_position(Gtk.WindowPosition.CENTER)
        window.connect("destroy", Gtk.main_quit)
        screen = Gdk.Screen.get_default()
        provider = Gtk.CssProvider()
        # provider.load_from_path("/home/wolandius/git_projects/redoswelcome/data/ui/style.css")
        provider.load_from_path("/usr/share/redos/redoswelcome/ui/style.css")
        Gtk.StyleContext.add_provider_for_screen(screen, provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
        architecture = "64-bit"
        if platform.machine() != "x86_64":
            architecture = str(platform.machine())
        new_features = "https://www.red-soft.ru/ru/blog" \
                       "/объявлена-новая-версия-ред-ос-на-основе-самого-свежего-ядра-linux"
        new_features_youtube = "https://www.youtube.com/watch?v=MkDVwhr8ZmQ"
        # distro-specific
        dist_name = "РЕД ОС"
        release = re.sub("Release:", "", os.popen("lsb_release -r").readline()).strip()
        if "n/a" in release:
            release = "8"
        elif "8.0" in release:
            release = "8"
        description = "standart" if "standard" in os.popen("lsb_release -d").readline().lower() else "certified"
        # description = "certified"
        edition = "Unknown DE or in Root mode"
        if os.getenv("XDG_CURRENT_DESKTOP") == "X-Cinnamon" or os.getenv("XDG_CURRENT_DESKTOP") == "Cinnamon":
            edition = "Cinnamon"
        elif os.getenv("XDG_CURRENT_DESKTOP") == "MATE":
            edition = "Mate"
        elif os.getenv("XDG_CURRENT_DESKTOP") == "GNOME":
            edition = "GNOME"
        elif os.getenv("XDG_CURRENT_DESKTOP") == "KDE":
            edition = "KDE"

        builder.get_object("label_version").set_text("%s %s" % (dist_name, release))
        builder.get_object("label_edition").set_text("%s %s" % (edition, architecture))

        self.stack_index_names = {
            0: "std_light_page",
            1: "alter_light_page",
            2: "std_dark_page",
            3: "alter_dark_page"
        }

        # Setup the main stack
        self.stack = builder.get_object("main_stack")
        self.stack.set_transition_type(Gtk.StackTransitionType.CROSSFADE)
        self.stack.set_transition_duration(150)
        self.theme = None
        if edition == "Mate":
            builder.get_object("mate_flow_box").set_visible(True)
            builder.get_object("button_mate_layout").connect("clicked", self.launch,
                                                             "/usr/share/mate-layout-chooser/mate-layout-chooser.py")
            builder.get_object("button_printers").connect("clicked", self.launch, "system-config-printer")
            builder.get_object("button_taskmanager").connect("clicked", self.launch, "mate-system-monitor")
            builder.get_object("button_prefered_apps").connect("clicked", self.launch,
                                                               "mate-default-applications-properties")
            builder.get_object("image_prefered_apps").set_from_icon_name("preferences-desktop-default-applications", 96)
            builder.get_object("button_settings").connect("clicked", self.launch, "mate-control-center")
            self.theme = Gio.Settings(schema="org.mate.interface").get_string("gtk-theme")
            builder.get_object("button_hardinfo").connect("clicked", self.launch, "hardinfo")
            self.button_standart_light_small = builder.get_object("button_standart_light_small")
            self.button_alter_light_small = builder.get_object("button_alter_light_small")
            self.button_standart_dark_small = builder.get_object("button_standart_dark_small")
            self.button_alter_dark_small = builder.get_object("button_alter_dark_small")
            self.stack_prev_button = builder.get_object("stack_prev_button")
            self.stack_next_button = builder.get_object("stack_next_button")
            self.themes_stack = builder.get_object("themes_stack")
            self.current_index = 0
            self.stack_prev_button.connect("clicked", self.call_change_stack_page_prev)
            self.stack_next_button.connect("clicked", self.call_change_stack_page_next)
            self.button_standart_light_small.connect("clicked", self.call_change_stack_page, 0)
            self.button_alter_light_small.connect("clicked", self.call_change_stack_page, 1)
            self.button_standart_dark_small.connect("clicked", self.call_change_stack_page, 2)
            self.button_alter_dark_small.connect("clicked", self.call_change_stack_page, 3)
            builder.get_object("set_std_light_button").connect("clicked", self.on_button_standart_clicked)
            builder.get_object("set_alter_light_button").connect("clicked", self.on_button_alter_clicked)
            builder.get_object("set_std_dark_button").connect("clicked", self.on_button_standart_dark_clicked)
            builder.get_object("set_alter_dark_button").connect("clicked", self.on_button_alter_dark_clicked)
            wm = Gio.Settings(schema="org.mate.session.required-components").get_string("windowmanager")
            if wm == "marco":
                builder.get_object("marco_radio").set_active(True)
            elif wm == "compiz":
                builder.get_object("compiz_radio").set_active(True)
            builder.get_object("marco_radio").connect("toggled", self.on_window_manager_toggled, "marco")
            builder.get_object("compiz_radio").connect("toggled", self.on_window_manager_toggled, "compiz")
        elif edition == "GNOME":
            builder.get_object("button_printers").connect("clicked", self.launch_args,
                                                          ["gnome-control-center", "printers"])
            builder.get_object("button_taskmanager").connect("clicked", self.launch, "gnome-system-monitor")
            builder.get_object("button_prefered_apps").connect("clicked", self.launch_args,
                                                               ["gnome-control-center", "default-apps"])
            builder.get_object("button_settings").connect("clicked", self.launch, "gnome-control-center")
            self.theme = Gio.Settings(schema="org.gnome.desktop.interface").get_string("gtk-theme")
            builder.get_object("button_hardinfo").connect("clicked", self.launch_args,
                                                          ["gnome-control-center", "about"])

        elif edition == "KDE":
            builder.get_object("button_printers").connect("clicked", self.launch, "kde-add-printer --add-printer")
            builder.get_object("button_taskmanager").connect("clicked", self.launch, "plasma-systemmonitor")
            builder.get_object("button_hardinfo").connect("clicked", self.launch, "kinfocenter")
            builder.get_object("button_prefered_apps").connect("clicked", self.launch_args,
                                                               ["systemsetting", "kcm_componentchooser"])
            builder.get_object("button_settings").connect("clicked", self.launch, "systemsettings")

        elif edition == "Cinnamon":
            builder.get_object("button_prefered_apps").connect("clicked", self.launch_args,
                                                               ["cinnamon-settings", "default"])
            builder.get_object("image_prefered_apps").set_from_icon_name("cs-default-applications", 96)
            builder.get_object("button_settings").connect("clicked", self.launch, "cinnamon-settings")
            self.theme = Gio.Settings(schema="org.cinnamon.desktop.interface").get_string("gtk-theme")
            builder.get_object("button_hardinfo").connect("clicked", self.launch, "hardinfo")
        else:
            builder.get_object("box_first_steps").remove(builder.get_object("box_settings"))
            builder.get_object("button_hardinfo").connect("clicked", self.launch, "hardinfo")

        # Action buttons
        builder.get_object("button_dnfdragora").connect("clicked", self.launch, "dnfdragora")
        builder.get_object("button_dnfdragora_upd_all").connect("clicked", self.launch_args,
                                                                ["dnfdragora", "--update-only"])
        builder.get_object("button_timeshift").connect("clicked", self.launch, "timeshift-launcher")
        builder.get_object("button_officeopen").connect("clicked", self.launch, "libreoffice")

        builder.get_object("button_network").connect("clicked", self.launch, "nm-connection-editor")
        builder.get_object("button_firewall").connect("clicked", self.launch, "firewall-config")

        builder.get_object("button_jointodomain").connect("clicked", self.launch_args,
                                                          ["beesu", "join-to-domain.sh -g"])

        self.button_yandex_browser = builder.get_object("button_yandex_browser")
        builder.get_object("button_yandex_browser").connect("clicked", self.yandex)
        builder.get_object("image_yandex_browser").set_from_file("/usr/share/redos/redoswelcome/ui/yandex-browser.png")

        self.button_r7_doceditors = builder.get_object("button_r7_doceditors")
        self.r7_doceditors_label = builder.get_object("r7_doceditors_label")
        builder.get_object("button_r7_doceditors").connect("clicked", self.r7_doceditors)
        builder.get_object("image_r7_doceditors").set_from_file("/usr/share/redos/redoswelcome/ui/р7-редактор.png")

        self.button_r7_organizer = builder.get_object("button_r7_organizer")
        self.r7_organizer_label = builder.get_object("r7_organizer_label")
        builder.get_object("button_r7_organizer").connect("clicked", self.r7_organizer)
        builder.get_object("image_r7_organizer").set_from_file("/usr/share/redos/redoswelcome/ui/р7-органайзер.png".encode("utf-8"))

        self.button_r7_graphics = builder.get_object("button_r7_graphics")
        self.r7_graphics_label = builder.get_object("r7_graphics_label")
        builder.get_object("button_r7_graphics").connect("clicked", self.r7_graphics)
        builder.get_object("image_r7_graphics").set_from_file("/usr/share/redos/redoswelcome/ui/р7-графика.png".encode("utf-8"))

        # builder.get_object("image_yandex_browser").set_from_file("ui/yandex-browser.png")

        # builder.get_object("image_youtube").set_from_file("/usr/share/redos/redoswelcome/ui/youtube.png")
        builder.get_object("image_tg").set_from_file("/usr/share/redos/redoswelcome/ui/telegram.png")
        builder.get_object("image_vk").set_from_file("/usr/share/redos/redoswelcome/ui/vk.png")
        builder.get_object("image_ok").set_from_file("/usr/share/redos/redoswelcome/ui/ok.png")
        builder.get_object("image_rutube").set_from_file("/usr/share/redos/redoswelcome/ui/rutube.png")
        builder.get_object("image_dzen").set_from_file("/usr/share/redos/redoswelcome/ui/dzen.png")

        builder.get_object("button_knowledgebase").connect("clicked", self.visit, "https://redos.red-soft.ru/base")
        builder.get_object("button_documentation").connect("clicked", self.visit,
                                                           "https://redos.red-soft.ru/documentation/")
        # builder.get_object("button_youtube").connect("clicked", self.visit,
        #                                              "https://www.youtube.com/channel/UCjsj4-tf1n0pGpa-TLhl-YQ/featured")

        # builder.get_object("button_youtube").hide()
        builder.get_object("button_telegram").connect("clicked", self.visit, "https://t.me/redsoft1")
        builder.get_object("button_vk").connect("clicked", self.visit, "https://vk.com/1redsoft")
        builder.get_object("button_ok").connect("clicked", self.visit, "https://ok.ru/group/58410339270801")
        builder.get_object("button_rutube").connect("clicked", self.visit, "https://rutube.ru/channel/23912197/")
        builder.get_object("button_dzen").connect("clicked", self.visit,
                                                  "https://zen.yandex.ru/id/622bab31563cdc2d9968ed7e")

        builder.get_object("button_aboutos").connect("clicked", self.visit, "https://redos.red-soft.ru/")
        # builder.get_object("button_new_features_youtube").connect("clicked", self.visit, new_features_youtube)
        button_redos_changelogs = builder.get_object("button_redos_changelogs")
        button_redos_changelogs.connect("clicked", self.visit,
                                        "https://redos.red-soft.ru/go/changelog/8-0-latest/") if "standart" in description else \
            button_redos_changelogs.connect("clicked", self.visit,
                                            "https://redos.red-soft.ru/go/changelog/8-0c-latest/")
        # text = _("Click the button to discover changelogs for Red OS") + f" {release}."
        # changelogs_label.set_text(text)

        builder.get_object("button_rdb").connect("clicked", self.visit, "https://reddatabase.ru/ru/")
        builder.get_object("button_redvirt").connect("clicked", self.visit,
                                                     "https://redos.red-soft.ru/product/red-virtualizatsiya/")
        builder.get_object("button_redadm").connect("clicked", self.visit,
                                                    "https://redos.red-soft.ru/product/redadm/")

        # Construct the stack switcher
        builder.get_object("list_navigation").connect("row-activated", self.sidebar_row_selected_cb)

        # Construct the bottom toolbar
        box = builder.get_object("toolbar_bottom")
        builder.get_object("version_label").set_text(f"v{VERSION}")
        checkbox = Gtk.CheckButton()
        checkbox.set_label(_("Show this dialog at startup"))
        if not os.path.exists(NORUN_FLAG):
            checkbox.set_active(True)
        checkbox.connect("toggled", self.on_button_toggled)
        box.pack_end(checkbox)

        scale = window.get_scale_factor()

        self.color = "green"
        self.alternative_mode = False
        self.yandex_label = builder.get_object("yandex_label")

        window.set_default_size(900, 600)
        window.show_all()

    def surface_for_path(self, path, scale):
        pixbuf = GdkPixbuf.Pixbuf.new_from_file(path)
        return Gdk.cairo_surface_create_from_pixbuf(pixbuf, scale)

    def sidebar_row_selected_cb(self, widget, row):
        if row.get_index() == 0:
            self.stack.set_visible_child_name("page_home")
        elif row.get_index() == 1:
            self.stack.set_visible_child_name("page_appearance_settings")
        elif row.get_index() == 2:
            self.stack.set_visible_child_name("page_first_steps")
        elif row.get_index() == 3:
            self.stack.set_visible_child_name("page_install_apps")
        elif row.get_index() == 4:
            self.stack.set_visible_child_name("page_documentation")
        elif row.get_index() == 5:
            self.stack.set_visible_child_name("page_about")

    def on_button_toggled(self, button):
        if button.get_active():
            if os.path.exists(NORUN_FLAG):
                os.system("rm -rf %s" % NORUN_FLAG)
        else:
            os.system("mkdir -p ~/.redoswelcome")
            os.system("touch %s" % NORUN_FLAG)

    def on_button_standart_clicked(self, button):
        theme = "RedOS-Red"
        wm_theme = "RedOS-Red"
        icons_theme = "RedOS"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def on_button_alter_clicked(self, button):
        theme = "RedOS-Blue"
        wm_theme = "RedOS-Blue"
        icons_theme = "RedOS-Alternative"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def on_button_old_clicked(self, button):
        theme = "RedOS"
        wm_theme = "RedOS"
        icons_theme = "redos"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def on_button_old_dark_clicked(self, button):
        theme = "RedOSBlack"
        wm_theme = "RedOSBlack"
        icons_theme = "redos-black"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def on_button_standart_dark_clicked(self, button):
        theme = "RedOS-Red-Dark"
        wm_theme = "RedOS-Red-Dark"
        icons_theme = "RedOS-Dark"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def on_button_alter_dark_clicked(self, button):
        theme = "RedOS-Blue-Dark"
        wm_theme = "RedOS-Blue-Dark"
        icons_theme = "RedOS-Alternative-Dark"
        cinnamon_theme = "RedOS"
        self.call_change_theme(theme, icons_theme, wm_theme, cinnamon_theme)

    def call_change_stack_page(self, button, index):
        self.current_index = index
        self.themes_stack.set_visible_child_name(self.stack_index_names[self.current_index])

    def call_change_stack_page_next(self, button):
        if self.current_index < 3:
            self.current_index += 1
        elif self.current_index == 3:
            self.current_index = 0
        print(self.stack_index_names[self.current_index])

        self.themes_stack.set_visible_child_name(self.stack_index_names[self.current_index])

    def call_change_stack_page_prev(self, button):
        if self.current_index > 0:
            self.current_index -= 1
        elif self.current_index == 0:
            self.current_index = 3
        print(self.stack_index_names[self.current_index])
        self.themes_stack.set_visible_child_name(self.stack_index_names[self.current_index])

    def call_change_theme(self, theme, icons_theme, wm_theme, cinnamon_theme):
        if os.getenv("XDG_CURRENT_DESKTOP") in ["Cinnamon", "X-Cinnamon"]:
            settings = Gio.Settings(schema="org.cinnamon.desktop.interface")
            settings.set_string("gtk-theme", theme)
            settings.set_string("icon-theme", icons_theme)
            Gio.Settings(schema="org.cinnamon.desktop.wm.preferences").set_string("theme", wm_theme)
            Gio.Settings(schema="org.cinnamon.theme").set_string("name", cinnamon_theme)

        elif os.getenv("XDG_CURRENT_DESKTOP") == "MATE":
            settings = Gio.Settings(schema="org.mate.interface")
            settings.set_string("gtk-theme", theme)
            settings.set_string("icon-theme", icons_theme)
            Gio.Settings(schema="org.mate.Marco.general").set_string("theme", wm_theme)

        elif os.getenv("XDG_CURRENT_DESKTOP") == "GNOME":
            settings = Gio.Settings(schema="org.gnome.desktop.interface")
            settings.set_string("gtk-theme", theme)
            settings.set_string("icon-theme", icons_theme)
            Gio.Settings(schema="org.gnome.metacity.theme").set_string("name", wm_theme)

    def on_window_manager_toggled(self, button, name):
        if button.get_active():
            Gio.Settings(schema="org.mate.session.required-components").set_string("windowmanager", name)
            win = InfoClass()
            win.print_simple_info(_("To change window manager - please, logout from current session."))

    def visit(self, button, url):
        subprocess.Popen(["xdg-open", url])

    def r7_doceditors(self, button):
        self.returncode = None
        self.label_start_text = _(
            "Professional document, spreadsheet and presentation editors.")
        self.button_r7_doceditors.set_sensitive(False)
        self.r7_doceditors_label.set_text(_("Preparing for installation"))

        inputs = ()
        async_worker = AsyncWorker(
            operation=self.download_r7_doceditors,
            operation_inputs=inputs,
            operation_callback=self.start_r7_install
        )
        async_worker.start()

    def r7_graphics(self, button):
        self.returncode = None
        self.label_start_text = _(
            "A tool for creating professional-grade diagrams, diagrams, graphs and business illustrations.")
        self.button_r7_graphics.set_sensitive(False)
        self.r7_graphics_label.set_text(_("Preparing for installation"))

        inputs = ()
        async_worker = AsyncWorker(
            operation=self.download_r7_graphics,
            operation_inputs=inputs,
            operation_callback=self.start_r7_install
        )
        async_worker.start()

    def r7_organizer(self, button):
        self.returncode = None
        self.label_start_text = _(
            "Application for managing mail, contacts and business schedule.")
        self.button_r7_organizer.set_sensitive(False)
        self.r7_organizer_label.set_text(_("Preparing for installation"))
        inputs = ()
        async_worker = AsyncWorker(
            operation=self.download_r7_organizer,
            operation_inputs=inputs,
            operation_callback=self.start_r7_install
        )
        async_worker.start()

    def download_r7_doceditors(self, *inputs):
        check_install = os.popen("rpm -qa | grep r7-office").readlines()
        check_repo_file = os.popen("rpm -qa | grep r7-release").readlines()
        if len(check_repo_file) == 0:
            if len(check_install) == 0:
                return "allr7o"
            else:
                return "orelease"
        else:
            if len(check_install) == 0:
                return "r7o"
            else:
                self.r7_doceditors_label.set_text(_("Package already installed"))
                return "1o"

    def download_r7_organizer(self, *inputs):
        check_install = os.popen("rpm -qa | grep r7organizer").readlines()
        check_repo_file = os.popen("rpm -qa | grep r7-release").readlines()
        if len(check_repo_file) == 0:
            if len(check_install) == 0:
                return "allr7org"
            else:
                return "orgrelease"
        else:
            if len(check_install) == 0:
                return "r7org"
            else:
                self.r7_organizer_label.set_text(_("Rpm already installed"))
                return "1org"

    def download_r7_graphics(self, *inputs):
        check_install = os.popen("rpm -qa | grep R7Grafika").readlines()
        check_repo_file = os.popen("rpm -qa | grep r7-release").readlines()
        if len(check_repo_file) == 0:
            if len(check_install) == 0:
                return "allr7g"
            else:
                return "grelease"
        else:
            if len(check_install) == 0:
                return "r7g"
            else:
                self.r7_graphics_label.set_text(_("Rpm already installed"))
                return "1g"

    def start_r7_install(self, worker, result, handler_data):
        """
        allr7o - means r7 repo +  r7-office
        allr7g - means r7 repo +  R7Grafika
        allr7org - means r7 repo +  r7organizer
        r7o - r7-office
        r7g - r7-R7Grafika
        r7org - r7organizer
        """
        result = worker.return_value(result)
        if result == "allr7o":
            win = RedosWelcomeDNF(["r7-office", "r7-release"], self.r7_doceditors_label, self.label_start_text,
                                  self.button_r7_doceditors)
        elif result == "allr7g":
            win = RedosWelcomeDNF(["R7Grafika", "r7-release"], self.r7_graphics_label, self.label_start_text,
                                  self.button_r7_graphics)
        elif result == "allr7org":
            win = RedosWelcomeDNF(["r7organizer", "r7-release"], self.r7_organizer_label, self.label_start_text,
                                  self.button_r7_organizer)
        elif result == "orelease":
            win = RedosWelcomeDNF(["r7-release"], self.r7_doceditors_label, self.label_start_text,
                                  self.button_r7_doceditors)
        elif result == "orgrelease":
            win = RedosWelcomeDNF(["r7-release"], self.r7_organizer_label, self.label_start_text,
                                  self.button_r7_organizer)
        elif result == "grelease":
            win = RedosWelcomeDNF(["r7-release"], self.r7_graphics_label, self.label_start_text,
                                  self.button_r7_graphics)
        elif result == "r7o":
            win = RedosWelcomeDNF(["r7-office"], self.r7_doceditors_label, self.label_start_text,
                                  self.button_r7_doceditors)
        elif result == "r7g":
            win = RedosWelcomeDNF(["R7Grafika"], self.r7_graphics_label, self.label_start_text, self.button_r7_graphics)
        elif result == "r7org":
            win = RedosWelcomeDNF(["r7organizer"], self.r7_organizer_label, self.label_start_text,
                                  self.button_r7_organizer)
        elif result == "1o":
            time.sleep(3)
            self.r7_doceditors_label.set_text(self.label_start_text)
            self.button_r7_doceditors.set_sensitive(True)
        elif result == "1org":
            time.sleep(3)
            self.r7_organizer_label.set_text(self.label_start_text)
            self.button_r7_organizer.set_sensitive(True)
        elif result == "1g":
            time.sleep(3)
            self.r7_graphics_label.set_text(self.label_start_text)
            self.button_r7_graphics.set_sensitive(True)

    def yandex(self, button):
        self.returncode = None
        self.label_start_text = _(
            "Install Yandex.Browser, a safe and fast Russian browser that supports TLS protocols according to GOST. It automatically translates videos, stores your passwords securely, and protects against viruses and scammers.")
        self.button_yandex_browser.set_sensitive(False)
        self.yandex_label.set_text(_("Preparing for installation"))

        inputs = ()
        async_worker = AsyncWorker(
            operation=self.download_yandex,
            operation_inputs=inputs,
            operation_callback=self.start_yandex_install
        )
        async_worker.start()

    def download_yandex(self, *inputs):
        check_install = os.popen("rpm -qa | grep yandex-browser-stable").readlines()
        check_repo_file = os.popen("rpm -qa | grep yandex-browser-release").readlines()
        if len(check_repo_file) == 0:
            if len(check_install) == 0:
                # wget_out = subprocess.Popen(["wget", "https://redos.red-soft.ru/go/yandex-browser",
                #                              "-O", "/tmp/yandex-browser.rpm"],
                #                             stdout=subprocess.PIPE,
                #                             stderr=subprocess.PIPE)
                # output, error = wget_out.communicate()
                # if wget_out.returncode != 0:
                #     self.yandex_label.set_text(error.decode("utf-8").strip())
                #     time.sleep(3)
                #     self.yandex_label.set_text(self.label_start_text)
                #     self.button_yandex_browser.set_sensitive(True)
                #     return 1
                # else:
                return "ya-all"
            else:
                return "ya-release"
        else:
            if len(check_install) == 0:
                return "ya-browser"
            else:
                self.yandex_label.set_text(_("Package already installed"))
                return 1

    def start_yandex_install(self, worker, result, handler_data):
        result = worker.return_value(result)
        if result == "ya-all":
            win = RedosWelcomeDNF(["yandex-browser-stable", "yandex-browser-release"], self.yandex_label,
                                  self.label_start_text, self.button_yandex_browser)
        elif result == "ya-release":
            win = RedosWelcomeDNF(["yandex-browser-release"], self.yandex_label, self.label_start_text,
                                  self.button_yandex_browser)
        elif result == "ya-browser":
            win = RedosWelcomeDNF(["yandex-browser-stable"], self.yandex_label, self.label_start_text,
                                  self.button_yandex_browser)
        elif result == 1:
            time.sleep(3)
            self.yandex_label.set_text(self.label_start_text)
            self.button_yandex_browser.set_sensitive(True)

    def launch(self, button, command):
        if "dnfdragora" in command:
            self.kill_dnfdragora()
        subprocess.Popen(command)

    def launch_args(self, button, command):
        for arg in command:
            if "dnfdragora" in arg:
                self.kill_dnfdragora()
                break
        subprocess.Popen(command)

    def pkexec(self, button, command):
        subprocess.Popen(["pkexec", command])

    def kill_dnfdragora(self):
        os.system("kill -9 $(ps aux | grep '[d]nfdragora --\|[d]nfdragora$' | awk '{print $2}')")


class InfoClass(Gtk.Window):
    def __init__(self):
        Gtk.Window.__init__(self)
        box = Gtk.Box()
        self.add(box)

    def print_simple_info(self, info):
        dialog = Gtk.MessageDialog(parent=self, flags=0, message_type=Gtk.MessageType.INFO, buttons=Gtk.ButtonsType.OK,
                                   text=_("Information"))
        dialog.format_secondary_text(info)
        dialog.run()
        dialog.destroy()

    def print_error(self, error):
        dialog = Gtk.MessageDialog(parent=self, flags=0, message_type=Gtk.MessageType.ERROR,
                                   buttons=Gtk.ButtonsType.CANCEL, text=_("Error"))
        dialog.format_secondary_text(error)
        dialog.run()
        dialog.destroy()


def main():
    app = RedosWelcome()
    Gtk.main()


if __name__ == "__main__":
    main()
